/**
 * Square: the class for one position on the Othello board.
 */

import java.awt.*;
   
public class Square extends java.awt.Canvas {
   // Properties common to all Squares.
   private static java.awt.Dimension size = new Dimension (20, 20); // The size of a Square.
   private static Color fillColor = Color.green;
      
   // The possible states of a Square. These are really properties of the abstract game, not
   // aspects of the display, so perhaps they really don't belong here; but in programming
   // terms, this seems a practical place for them to be defined.
   public static final int EMPTY = 0;
   public static final int BLACK = 1;
   public static final int WHITE = 2;
   
   // The actual state of this Square.
   private int state = EMPTY; // A Square is always created empty.
   
   // Where is this Square on the Othello board?
   private int myRow;
   private int myCol;
   
   /**
    * Square constructor.
    */
   
   public Square(int row, int col) {
      super();
      myRow = row;
      myCol = col;
   }

   /**
    * getState: what is the current state of this Square?
    */
    
   public int getState ( ) {
      return state;
   }

   /**
    * getMinimumSize: a newer version of "minimumSize".
    */
   public Dimension getMinimumSize ( ) {
      return size;
   }   

   /**
    * paint: actually make the picture of the pebble.
    * @param g java.awt.Graphics
    */
   
   public void paint (Graphics g) {
      // Draw the border and fill in the square.
      g.setColor (Color.black);
      g.drawRect(1, 1, size.width - 2, size.height - 2);
      g.setColor (fillColor);
      g.fillRect(2, 2, size.width - 3, size.height - 3);
      
      // Draw the pebble.
      if (state == EMPTY)
         return;
      g.setColor (state == BLACK ? Color.black : Color.white);
      g.fillOval (size.width/6, size.height/6, size.width*2/3 + 1, size.height*2/3 + 1);
   }

   /**
    * getPreferredSize: a newer version of "preferredSize".
    */
   public Dimension getPreferredSize ( ) {
      return getMinimumSize ( );
   }   

   /**
    * setSize: a STATIC method, so the sizes for all Squares are modified at once.
    * @param dim int
    */
   
   public static void setSize (int dim) {
      size.setSize (dim, dim);
   }

   /**
    * setState: change the state of this Square to the specified newState.
    * @param newState int
    */
   
   public void setState (int newState) {
      // Is the new state legal?
      if (newState != EMPTY && newState != BLACK && newState != WHITE) {
         System.out.println ("Square.setState(): specified state is not valid");
         return;
      }
      
      // It's legal, so let's use it.
      state = newState;
      repaint();
   }
}
